# ![MOSQITO Logo](https://raw.githubusercontent.com/Eomys/MoSQITo/master/logo.png) MOSQITO

## Background

Sound quality (SQ) metrics are developed by acoustic engineers and 
researchers to provide an objective assessment of the pleasantness of a
sound. Different metrics exist depending on the nature of the sound to
be tested. Some of these metrics are already standardized, while some
others rely on scientific articles and are still under active
development. The calculation of some sound quality metrics are included
in major commercial acoustic and vibration measurement and analysis
software. However, some of the proposed metrics results from in-house
implementation and can be dependent from one system to another. Some
implementations may also lack of complete documentation and validation
on publicly available standardized sound samples. Several
implementations of SQ metrics in different languages can been found
online, confirming the interest of the engineering and scientific
community, but they often use Matlab signal processing commercial
toolbox.

Besides the metrics, sound quality studies requires several tool like audio signal filtering or jury testing procedure fore instance.

## Objectives

The objective of MOSQITO is therefore to provide a unified and modular development framework of key sound quality tools (including key SQ metrics) with open-source object-oriented technologies, favoring reproducible science and efficient shared scripting among engineers, teachers and researchers
community. The development roadmap of the project is presented in more details in the [documentation](./documentation/scope.md). 

It is written in Python, one of the most popular free programming language in the scientific computing community. It is meant to be highly documented (use of Jupyter notebooks, tutorials) and validated with reference sound samples and scientific publications.

## Origin of the project

[EOMYS ENGINEERING](https://eomys.com/?lang=en) initiated this open-source project in 2020 for the study of electric motor sound quality. The project is now backed by [Green Forge Coop](https://www.linkedin.com/company/greenforgecoop/) non profit organization, who also supports the development of [Pyleecan](https://www.pyleecan.org) electrical machine simulation software.

## Documentation

Tutorials are available in the [tutorials](./tutorials/) folder. Documentation and validation of the MOSQITO functions are available in the [documentation](./documentation/) folder.

## Contact

You can contact us on Github by opening an issue (to request a feature, ask a question or report a bug).

## How to cite MOSQITO

If you use MOSQITO for your research activities and need to cite the software in a publication, please use the following citation:
TODO
